/*   MATCH_STRING.C   is a routine which will compare an input string
 *			(properly null terminated) with a table of strings.
 *			Table is an array of structure PHRASE_PAIR --
 *			a string pointer, and an integer to be returned
 *			to indicate a match.   The last element in the
 *			table must have an integer code of 0 (therefore
 *			no other elements may use 0 as their code).
 *			EXACT is a flag ... if true, then a match will
 *			only be found if the strings exactly match.  Else,
 *			there will be a match if one is a subset of the
 *			other.
 */
struct phrase_pair { 
		char *phrase;
		int   code;
		   };
#define  ambiguous -1
#ifndef  bool
#include  curses
#endif
#ifndef  EOF
#include  stdio
#endif


match_string (string, table, exact)
char	*string;
struct phrase_pair  *table;
bool	exact;			/* if true, requires exact match */

/*
 *
 * INPUTS:
 *	string:         pointer to a character string to check.
 *
 *	table:          Pointer to array of phrase_pair structures.
 *			Table that contains all the legal options
 *			and their associated codes.
 *
 *	exact:		Boolean (short int) flag. If true, requires
 *			exact match, rather than unique substring.
 *
 * OUTPUTS:
 *	returns:       	Returns the code of the matched phrase.
 *			Returns 0 if no match, or "ambiguous" if more than
 *			one match.
 *
 * ASSUMPTIONS:
 *			struct phrase_pair { char *phrase;
 *					     int   code;  };
 *			#define  ambiguous -1
 *			#include curses.h
 *
 * SIDE EFFECTS:
 *	None.
 *
 */

{
	int	num_matches=0, i=0, j=0, matched_code=0;
	bool	match=1;
	struct	phrase_pair  *ptr;
	char	c;


  /* Check for a match with the table.  If there is one, make sure
    that it is not ambiguous. */

	ptr = table;						/* point to table */
	while (ptr->code)					/* if code==0, end of table */
	    {	j = 0;						/* initialize on each pass */
		match = (string[j] != '\0');			/* ditto; also, null string mustn't match */
		while (string[j] != '\0' && ptr->phrase[j] != '\0' && match)
		    {	match = (string[j] == ptr->phrase[j]);
			j++;
		    }
		if (exact && match)				/* dropped out because one or the other string ended */
			match = (string[j] == ptr->phrase[j]);
		if (match)
		    {	num_matches++;
			matched_code = ptr->code;
		    }
		ptr++;						/* keep checking, to insure no ambiguity */
	    }							/* end of table */

	if (num_matches > 1)
		matched_code = ambiguous;
	return (matched_code);
}
