$ verify = 'F$VERIFY(0)'
$!.. BATJOBTST.COM		Test for a batch job by name
$ IF p1 .EQS "" THEN $ EXIT	F$VERIFY(verify).OR.1
$ inhibit = %X10000000		!Condition code bit to inhibit message output
$ ON ERROR THEN $ EXIT	F$VERIFY(verify).OR.$status.OR.inhibit
$ test_state = "P"		!Test for state of "Pending" or "Holding"
$ IF F$ELEMENT( 1, "/", p1) .EQS. "/" THEN $ GOTO NO_QUALIFIER
$ test_state = F$EDIT( F$EXTRACT( 0, 1, F$ELEMENT( 1, "/", p1)), "UPCASE")
$ p1 = F$ELEMENT( 0, "/", p1)	!Get job name w/o qualifier
$ IF (test_state .NES. "A") .AND. (test_state .NES. "E") .AND. -
	(test_state .NES. "P") THEN $ GOTO BAD_QUALIFIER
$NO_QUALIFIER:
$ IF p2 .EQS. "" THEN p2 = "SYS$BATCH"
$ IF F$LOGICAL( p2) .NES. "" THEN p2 = F$LOGICAL( p2)	!Logical "queue" name
$ IF p3 .EQS. "" THEN p3 = F$EDIT( F$GETJPI("", "USERNAME"), "COLLAPSE")
$ SHOW QUEUE /BATCH /ALL /OUTPUT=BATCHQ.TMP  'p2'	!Show all jobs in queue
$ JOB_TIME == ""			! Init for null return
$ OPEN/READ  BATCHQ:  BATCHQ.TMP
$ line_number = 0
$READ_LOOP:				! Read output of SHOW QUEUE command
$  READ/END_OF_FILE=END_LOOP  BATCHQ:  record
$  line_number = line_number + 1	!Lines 1-4 are heading and ignored
$  IF line_number .LT. 5 THEN $ GOTO READ_LOOP
$  record = F$EDIT( record, "COMPRESS,TRIM")
$  IF F$ELEMENT( 1, " ", record) .NES. " " THEN $ GOTO NOT_CONTINUED
$    READ/END_OF_FILE=END_LOOP  BATCHQ:  continuation	!Read continuation line
$    record = record + " " + F$EDIT( continuation, "COMPRESS,TRIM")
$NOT_CONTINUED:				!Will have concatenated continuations.
$  IF test_state .EQS. "A" THEN $ GOTO STATE_SELECTED
$  state_of_job = F$ELEMENT( 3," ", record)
$  IF (test_state .EQS. "E") .AND. -
      (state_of_job .EQS. "Executing") THEN $ GOTO STATE_SELECTED
$  IF (test_state .EQS. "P") .AND. ((state_of_job .EQS. "Pending") .OR. -
      (state_of_job .EQS. "Holding")) THEN $ GOTO STATE_SELECTED
$  GOTO READ_LOOP
$STATE_SELECTED:			!Found in valid state, check name/user
$  IF F$ELEMENT( 0," ", record) .NES. p1 THEN $ GOTO READ_LOOP
$  IF p3 .EQS. "*" THEN $ GOTO SKIP_USERNAME_CHECK
$    IF F$ELEMENT( 1," ", record) .NES. p3 THEN $ GOTO READ_LOOP
$SKIP_USERNAME_CHECK:
$ CLOSE BATCHQ:
$ DELETE BATCHQ.TMP;*
$ EXIT  F$VERIFY(verify).OR.1
$END_LOOP:			!No job found, return WARNING
$ CLOSE BATCHQ:
$ DELETE BATCHQ.TMP;*
$ EXIT	F$VERIFY(verify).OR.inhibit
$BAD_QUALIFIER:
$ WRITE SYS$OUTPUT "%BATJOBTST-F-UNKQUAL, unknown status qualifier"
$ EXIT	F$VERIFY(verify).OR.inhibit.OR.4
$!=============================================================================
$! BATJOBTST.COM
$!
$!+ BATJOBTST
$! Test a batch queue for a specific batch job by name:
$!
$!	@FERMI$UTIL:BATJOBTST  jobname[qualifier]  [queue]  [username]
$!
$! The P1 parameter gives the job name of the batch job whose existence
$! is being tested.  If no P1 parameter is given, the procedure exits
$! with a success status.  The P2 parameter selects the batch queue
$! being searched, if none is specified, SYS$BATCH is used.  The P3
$! parameter specifies the username whose jobs are to be searched.
$! If no user is specified, then the current process's username is used.
$! If P3 is "*", then the username is not used to limit which batch
$! jobs are examined.  The qualifier determines the status of the batch
$! jobs scanned for a match (see "Qualifiers" subtopic).
$!
$! The procedure exits returning a SUCCESS code if a matching batch
$! job (match by name, user and status) is found in the specified queue.
$! The procedure returns a WARNING status code if no such batch job
$! is found.  Internal errors (such as non-existant batch queue) will
$! return ERROR and FATAL status.
$!2 Qualifiers
$! The qualifier can only be placed on the first parameter, the batch
$! job name.  The qualifier determines the status of the searched jobs.
$!/ANY
$! All batch jobs in the queue, regardless of status are searched.
$! The default is /PENDING, to only search pending jobs.
$!/EXECUTING
$! Only executing jobs are scanned for the specified job name and user.
$! The default is /PENDING, to only search pending jobs.
$!/PENDING
$! Only pending or holding jobs are scanned for the specified job name
$! and user.  This is the default.
$!-
$! The assumed format of the SHOW QUEUE output includes the following
$! for the format of lines describing jobs, the first 4 lines are headings
$! and queue identification and are ignored:
$!
$!	Columns	Item#	Contents
$!	-------	-----	--------
$!	3-17	0	Job name
$!	19-30	1	Username of batch job
$!	32-37	2	Entry number in queue
$!	39-...	3,4	Status: "Executing", "Pending", "Holding" or
$!			"Holding until".
$!	53-69	5,6	Absolute date if "Holding until".
$!
$! The various fields are separated by spaces, so the line can have leading
$! and trailing spaces trimmed and multiple spaces compressed, then the
$! F$ELEMENT() lexical function can be used to access the various items
$! using a space as the delimiter.
$!=============================================================================
$! Author:	Frank J. Nagy	Fermilab Accelerator Controls
$! Modifications:
$!  09-Jun-85	FJN	Created from BATQUEDEL.COM
$!  10-Jun-85	FJN	Debugged (wrong index for F$ELEMENT(), start with 0)
$!			and provided for continuation lines when long job names
$!  24-Oct-85	FJN	Check for queue name is really a logical name (which is
$!			assumed to re-direct to a real queue name).
